@@ -15,7 +15,7 @@
 #
 
 
-from flet_manager.app import App
+from .app import App
 
 
 __all__ = [
