@@ -16,10 +16,12 @@
 
 
 from flet_manager.views.base import BaseView
+from flet_manager.views.main import MainView
 from flet_manager.views.error import ErrorView
 
 
 __all__ = [
     'BaseView',
+    'MainView',
     'ErrorView',
 ]
