@@ -19,11 +19,13 @@ from inspect import getfullargspec
 
 from flet_core import Text, View
 
+from flet_manager.utils import Client
+
 
 class BaseView(View):
     route: str = '/'
-    app: None
-    controls: list
+    title: str = 'View'
+    client: Client
     params: dict
 
     def __init__(self, **kwargs):
@@ -50,6 +52,8 @@ class BaseView(View):
     async def restart(self):
         await self.build()
         await self.update_async()
+        await self.on_load()
+        await self.update_async()
 
-    async def get(self):
-        return self
+    async def on_load(self):
+        pass
