@@ -22,12 +22,10 @@ from flet_manager.views.base import BaseView
 
 class ErrorView(BaseView):
     route: str = '/error'
-    app: None
-    controls: list
-    params: dict
+    title: str = 'Error'
 
-    async def go_back(self, e):
-        await self.app.view_change(go_back=True)
+    async def go_back(self, _):
+        await self.client.change_view(go_back=True)
 
     async def build(self):
         self.controls = [
